"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .llmchoice import LLMChoice, LLMChoiceTypedDict
from .llmtokenusage import LLMTokenUsage, LLMTokenUsageTypedDict
from livepeer_ai.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class LLMResponseTypedDict(TypedDict):
    id: str
    model: str
    created: int
    usage: LLMTokenUsageTypedDict
    choices: List[LLMChoiceTypedDict]


class LLMResponse(BaseModel):
    id: str

    model: str

    created: int

    usage: LLMTokenUsage

    choices: List[LLMChoice]
