"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from livepeer_ai.types import BaseModel
from typing_extensions import TypedDict


class LLMMessageTypedDict(TypedDict):
    role: str
    content: str


class LLMMessage(BaseModel):
    role: str

    content: str
