"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from livepeer_ai.models.components import (
    httpmetadata as components_httpmetadata,
    livevideotovideoresponse as components_livevideotovideoresponse,
)
from livepeer_ai.types import BaseModel
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class GenLiveVideoToVideoResponseTypedDict(TypedDict):
    http_meta: components_httpmetadata.HTTPMetadataTypedDict
    live_video_to_video_response: NotRequired[
        components_livevideotovideoresponse.LiveVideoToVideoResponseTypedDict
    ]
    r"""Successful Response"""


class GenLiveVideoToVideoResponse(BaseModel):
    http_meta: Annotated[
        Optional[components_httpmetadata.HTTPMetadata], pydantic.Field(exclude=True)
    ] = None

    live_video_to_video_response: Optional[
        components_livevideotovideoresponse.LiveVideoToVideoResponse
    ] = None
    r"""Successful Response"""
